==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_powerroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function CannotEscape()
    PRI()
    TUR()MS4("\n不能逃跑！")NOD()
end

function CannotCheck()
    PRI()
    TUR()MS4("\n现在不是干这个事的时候！")NOD()
end

--去外面
function Door_GoPath()
    if(FLJ("InBossFight")) then
        CannotEscape()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPath",0,1)FAO(3)TRA("CS_path","E0091",177,20)
    end
end
--电源开关
function PowerSwitch()
    if(FLJ("InBossFight")) then
        CannotCheck()
    elseif(FLJ("PowerOn")) then
        KEY()
        TUR()MS4("\n电源正常运作中。")NOD()
    else
        KEY()
        MS4("风扇的电源为OFF。")NOD()
        CAT("\n马鲁可的电源为OFF。")NOD()CLR()
        CAT("\n要启动电源吗？")YNJ()CLO()
        if(YES()) then
            WAI(32)
            SOU("CS_043_computer_beep")
            FLP("PowerOn")
            FLP("JellyAppear")
            SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
            SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
            WAI(32)
            MS4("\n电源已启动。")NOD()CLO()
            ANP("Malco1",10,1)WAI(20)AMC(0,0,PLY())SLR(0,PLY())WAI(450)
            CMU("CS_Gravity")
            MS4("发现侵入者！！")NOD()
            CAT("\n立刻 将侵入者消灭！！")NOD()WAI(50)
            CNP("MalcoBoss","CS_boss_malco",0,1)
            MNP("MalcoBoss","Malco1")
            BSL("MalcoBoss")
            DNP("Malco1")
            FLP("InBossFight")
        end
    end
end
--调查马鲁可
function Malco1()
    KEY()
    MS4("\n一个没有启动电源的机器人。")NOD()
end

--战胜马鲁可后
function MalcoBoss()
    KEY()
    CNP("MalcoBoss","CS_malco_animate",0,1)
    ANP("MalcoBoss",200)
    WAI(60)
    CMU("CS_Fanfale3")
    MS4("\n马鲁可 被击败了！")WAI(140)NOD()
    CMU("CS_Vivi")
    FLS("InBossFight")
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/map/CS_powerroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function CannotEscape()
    PRI()
    TUR()MS4("\n不能逃跑！")NOD()
end

function CannotCheck()
    PRI()
    TUR()MS4("\n现在不是干这个事的时候！")NOD()
end

--去外面
function Door_GoPath()
    if(FLJ("InBossFight")) then
        CannotEscape()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPath",0,1)FAO(3)TRA("CS_path","E0091",177,20)
    end
end
--电源开关
function PowerSwitch()
    if(FLJ("InBossFight")) then
        CannotCheck()
    elseif(FLJ("PowerOn")) then
        KEY()
        TUR()MS4("\n电源正常运作中。")NOD()
    else
        KEY()
        MS4("风扇的电源为OFF。")NOD()
        CAT("\n马鲁可的电源为OFF。")NOD()CLR()
        CAT("\n要启动电源吗？")YNJ()CLO()
        if(YES()) then
            WAI(32)
            SOU("CS_043_computer_beep")
            FLP("PowerOn")
            FLP("JellyAppear")
            SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
            SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
            WAI(32)
            MS4("\n电源已启动。")NOD()CLO()
            ANP("Malco1",10,1)WAI(20)AMC(0,0,PLY())SLR(0,PLY())WAI(450)
            CMU("CS_Gravity")
            MS4("发现侵入者！！")NOD()
            CAT("\n立刻 将侵入者消灭！！")NOD()WAI(50)
            CNP("MalcoBoss","CS_boss_malco",0,1)
            MNP("MalcoBoss","Malco1")
            BSL("MalcoBoss")
            DNP("Malco1")
            FLP("InBossFight")
            SKP("QuickMalcoBoss")
        end
    end
end
--调查马鲁可
function Malco1()
    KEY()
    MS4("\n一个没有启动电源的机器人。")NOD()
end

--战胜马鲁可后
function MalcoBoss()
    KEY()
    CNP("MalcoBoss","CS_malco_animate",0,1)
    ANP("MalcoBoss",200)
    WAI(60)
    CMU("CS_Fanfale3")
    MS4("\n马鲁可 被击败了！")WAI(140)NOD()
    CMU("CS_Vivi")
    FLS("InBossFight")
    SKS("QuickMalcoBoss")
end

function QuickMalcoBoss()
    PRI()
    FLP("PowerOn")
    FLP("JellyAppear")
    SNP("CS_powerroom_screen",23,14,0,"mainLayer","")
    SNP("CS_powerroom_wave",23,12,0,"mainLayer","")
    ANP("Malco1",10,1)AMC(0,0,PLY())SLR(0,PLY())
    FAI(1)
    KEY()
    CMU("CS_Gravity")
    CNP("MalcoBoss","CS_boss_malco",0,1)
    MNP("MalcoBoss","Malco1")
    BSL("MalcoBoss")
    DNP("Malco1")
    FLP("InBossFight")
end
